Function http_box::byte::is_encoded
[−]
[src]
pub fn is_encoded(byte: u8) -> bool
Indicates that a byte should be encoded to hex.
This encodes all control characters 0x00 thru 0x1F, DEL 0x7F, SPC 0x20, and all
ISO-Latin characters 0x80 thru 0xFF.
This follows the list of delimiters listed in RFC 3986, as well as additional characters known to be used by HTTP and HTML parsers that for safety reasons are also included.
General delimiters:
:, /, ?, #, [, ], @
Sub-delimiters:
!, $, &, ', (, ), *, +, ,, ;, =
Additional characters:
<, >, \, ^, `, {, }, |