Struct http_box::http2::Flags [] [src]

pub struct Flags { /* fields omitted */ }

Flags.

Methods

impl Flags
[src]

Flags.

Create a new Flags from a u8.

Convert this flags to its byte value.

Indicates that the ack flag has been set.

Indicates that the flags are empty.

Indicates that the end headers flag has been set.

Indicates that the end stream flag has been set.

Indicates that the padded flag has been set.

Indicates that the priority flag has been set.