Enum http_box::http1::ParserState [] [src]

#[repr(u8)]
pub enum ParserState { Dead, StripDetect, Detect1, Detect2, Detect3, Detect4, Detect5, UpperRequestMethod, LowerRequestMethod, StripRequestUrl, RequestUrl, StripRequestHttp, RequestHttp1, RequestHttp2, RequestHttp3, RequestHttp4, RequestHttp5, RequestVersionMajor, RequestVersionMinor, ResponseVersionMajor, ResponseVersionMinor, StripResponseStatusCode, ResponseStatusCode, StripResponseStatus, ResponseStatus, InitialEnd, PreHeadersLf1, PreHeadersCr2, StripHeaderName, FirstHeaderName, UpperHeaderName, LowerHeaderName, StripHeaderValue, HeaderValue, HeaderQuotedValue, HeaderEscapedValue, HeaderCr1, HeaderLf1, HeaderCr2, HeaderLf2, ChunkLength1, ChunkLength2, ChunkLengthCr, StripChunkExtensionName, UpperChunkExtensionName, LowerChunkExtensionName, StripChunkExtensionValue, ChunkExtensionValue, ChunkExtensionQuotedValue, ChunkExtensionQuotedValueFinished, ChunkExtensionEscapedValue, ChunkExtensionFinished, ChunkLengthLf, ChunkData, ChunkDataCr1, ChunkDataLf1, MultipartHyphen1, MultipartHyphen2, MultipartBoundary, MultipartDetectData, MultipartDataByByte, MultipartDataByLength, MultipartDataByLengthCr, MultipartDataByLengthLf, MultipartDataByByteLf, MultipartBoundaryCr, MultipartBoundaryLf, MultipartEnd, UrlEncodedName, UrlEncodedNameAmpersand, UrlEncodedNameHex1, UrlEncodedNameHex2, UrlEncodedNamePlus, UrlEncodedValue, UrlEncodedValueHex1, UrlEncodedValueHex2, UrlEncodedValuePlus, BodyFinished, Finished, }

Parser states.

Variants

An error was returned from a call to Parser::parse().

Stripping linear white space before request/response detection.

Detect request/response byte 1.

Detect request/response byte 2.

Detect request/response byte 3.

Detect request/response byte 4.

Detect request/response byte 5.

Parsing upper-caed request method.

Parsing lower-cased request method.

Stripping linear white space before URL.

Parsing URL.

Stripping linear white space before request HTTP version.

Parsing request HTTP version byte 1.

Parsing request HTTP version byte 2.

Parsing request HTTP version byte 3.

Parsing request HTTP version byte 4.

Parsing request HTTP version byte 5.

Parsing request HTTP major version.

Parsing request HTTP minor version.

Parsing response HTTP major version.

Parsing response HTTP minor version.

Stripping linear white space before response status code.

Parsing response status code.

Stripping linear white space before response status.

Parsing response status.

Parsing initial request/response line has finished.

Parsing pre-header first line feed.

Parsing pre-header potential second carriage return.

Stripping linear white space before header name.

Parsing first byte of header name.

Parsing upper-cased header name.

Parsing lower-cased header name.

Stripping linear white space before header value.

Parsing header value.

Parsing quoted header value.

Parsing escaped header value.

Parsing first carriage return after status line or header value.

Parsing first line feed after status line or header value.

Parsing second carriage return after status line or header value.

Parsing second line feed after status line or header value.

Parsing chunk length byte 1.

Parsing chunk length byte 2.

Parsing chunk length carriage return or semi-colon.

Stripping linear white space before chunk extension name.

Parsing upper-cased chunk extension.

Parsing lower-cased chunk extension.

Stripping linear white space before chunk extension value.

Parsing chunk extension value.

Parsing quoted chunk extension value.

Parsing potential semi-colon or carriage return after chunk extension quoted value.

Parsing escaped chunk extension value.

End of chunk extension.

Parsing line feed after chunk length.

Parsing chunk data.

Parsing carriage return after chunk data.

Parsing line feed after chunk data.

Parsing pre boundary hyphen 1.

Parsing pre boundary hyphen 2.

Parsing multipart boundary.

Detecting multipart data parsing mechanism.

Parsing multipart data by byte.

Parsing multipart data by content length.

Parsing carriage return after data by length.

Parsing line feed after data by length.

Parsing potential line feed after data by byte.

Parsing post boundary carriage return or hyphen.

Parsing post boundary line feed.

Parsing last boundary second hyphen that indicates end of multipart body.

Parsing URL encoded name.

Parsing URL encoded name ampersand or semicolon.

Parsing URL encoded name hex sequence byte 1.

Parsing URL encoded name hex sequence byte 2.

Parsing URL encoded name plus sign.

Parsing URL encoded value.

Parsing URL encoded value hex sequence byte 1.

Parsing URL encoded value hex sequence byte 2.

Parsing URL encoded value plus sign.

End of body parsing.

Parsing entire message has finished.