Struct http_box::http2::Flags
[−]
[src]
pub struct Flags { /* fields omitted */ }Flags.
Methods
impl Flags[src]
Flags.
fn from_u8(byte: u8) -> Flags
Create a new Flags from a u8.
fn as_byte(&self) -> u8
Convert this flags to its byte value.
fn is_ack(&self) -> bool
Indicates that the ack flag has been set.
fn is_empty(&self) -> bool
Indicates that the flags are empty.
fn is_end_headers(&self) -> bool
Indicates that the end headers flag has been set.
fn is_end_stream(&self) -> bool
Indicates that the end stream flag has been set.
fn is_padded(&self) -> bool
Indicates that the padded flag has been set.
fn is_priority(&self) -> bool
Indicates that the priority flag has been set.